@@ -8,35 +8,28 @@ use Carp;
 our @ISA = qw( Acme::MetaSyntactic::RemoteList );
 
 sub init {
-    my ($self, $data) = @_;
     my $class = caller(0);
-
-    $data ||= Acme::MetaSyntactic->load_data($class);
+    my $data  = Acme::MetaSyntactic->load_data($class);
     no strict 'refs';
 
-    # note: variables mentioned twice to avoid a warning
-
-    my $sep = ${"$class\::Separator"} = ${"$class\::Separator"} ||= '/';
-    my $tail = qr/$sep?[^$sep]*$/;
-
     # compute all categories
     my @categories = ( [ $data->{names}, '' ] );
     while ( my ( $h, $k ) = @{ shift @categories or []} ) {
         if ( ref $h eq 'HASH' ) {
             push @categories,
-                map { [ $h->{$_}, ( $k ? "$k$sep$_" : $_ ) ] } keys %$h;
+                map { [ $h->{$_}, ( $k ? "$k/$_" : $_ ) ] } keys %$h;
         }
         else {    # leaf
             my @items = split /\s+/, $h;
             while ($k) {
                 push @{ ${"$class\::MultiList"}{$k} }, @items;
-                $k =~ s!$tail!!;
+                $k =~ s!/?[^/]*$!!;
             }
         }
     }
 
-    ${"$class\::Default"} = ${"$class\::Default"} = $data->{default} || ':all';
-    ${"$class\::Theme"} = ${"$class\::Theme"} = ( split /::/, $class )[-1];
+    ${"$class\::Default"} = $data->{default} || ':all';
+    ${"$class\::Theme"} = ( split /::/, $class )[-1];
 
     *{"$class\::import"} = sub {
         my $callpkg = caller(0);
@@ -45,7 +38,7 @@ sub init {
         *{"$callpkg\::meta$theme"} = sub { $meta->name(@_) };
     };
 
-    ${"$class\::meta"} = ${"$class\::meta"} = $class->new();
+    ${"$class\::meta"} = $class->new();
 }
 
 sub name {
@@ -87,16 +80,7 @@ sub new {
         if $self->{category} ne ':all'
         && !exists ${"$class\::MultiList"}{ $self->{category} };
 
-    $self->_compute_base();
-    return $self;
-}
-
-sub _compute_base {
-    my ($self) = @_;
-    my $class = ref $self;
-
     # compute the base list for this category
-    no strict 'refs';
     my %seen;
     $self->{base} = [
         grep { !$seen{$_}++ }
@@ -105,7 +89,8 @@ sub _compute_base {
         ? ( keys %{"$class\::MultiList"} )
         : ( $self->{category} )
     ];
-    return;
+
+    return $self;
 }
 
 sub category { $_[0]->{category} }
@@ -118,14 +103,6 @@ sub categories {
     return keys %{"$class\::MultiList"};
 }
 
-sub has_category {
-    my ($class, $category) = @_;
-    $class = ref $class if ref $class;
-
-    no strict 'refs';
-    return exists ${"$class\::MultiList"}{$category};
-}
-
 sub theme {
     my $class = ref $_[0] || $_[0];
     no strict 'refs';
@@ -238,10 +215,6 @@ Return the selected category for this instance.
 
 Return the categories supported by the theme (except C<:all>).
 
-=item has_category( $category )
-
-Return a boolean value indicating if the theme contains the given category.
-
 =item theme()
 
 Return the theme name.
